function t_opf_dc(quiet)
%T_OPF_DC  Tests for DC optimal power flow.

%   MATPOWER
%   $Id: t_opf_dc.m,v 1.1 2007/06/06 20:42:47 ray Exp $
%   by Ray Zimmerman, PSERC Cornell
%   Copyright (c) 2004-2007 by Power System Engineering Research Center (PSERC)
%   See http://www.pserc.cornell.edu/matpower/ for more info.

if nargin < 1
    quiet = 0;
end

num_tests = 5;

t_begin(num_tests, quiet);

[GEN_BUS, PG, QG, QMAX, QMIN, VG, MBASE, GEN_STATUS, PMAX, PMIN, ...
    MU_PMAX, MU_PMIN, MU_QMAX, MU_QMIN, PC1, PC2, QC1MIN, QC1MAX, ...
    QC2MIN, QC2MAX, RAMP_AGC, RAMP_10, RAMP_30, RAMP_Q, APF] = idx_gen;
[F_BUS, T_BUS, BR_R, BR_X, BR_B, RATE_A, RATE_B, RATE_C, ...
    TAP, SHIFT, BR_STATUS, PF, QF, PT, QT, MU_SF, MU_ST, ...
    ANGMIN, ANGMAX, MU_ANGMIN, MU_ANGMAX] = idx_brch;

casefile = 't_case9_opf';
if quiet
    verbose = 0;
else
    verbose = 0;
end
mpopt = mpoption('OUT_ALL', 0, 'VERBOSE', verbose);

%% get solved DC power flow case from MAT-file
load soln9_dcopf;       %% defines bus_soln, gen_soln, branch_soln, f_soln

%% run DC OPF
if have_fcn('bpmpd') | have_fcn('quadprog') | have_fcn('qp')
	t = 'DC OPF : ';
	mpopt = mpoption('OUT_ALL', 0, 'VERBOSE', verbose);
	[baseMVA, bus, gen, gencost, branch, f, success, et] = rundcopf(casefile, mpopt);
	t_ok(success, [t 'success']);
	t_is(f, f_soln, 3, [t 'f']);
	t_is(bus, bus_soln, 3, [t 'bus']);
	t_is(gen, gen_soln, 3, [t 'gen']);
	t_is(branch, branch_soln, 3, [t 'branch']);
else
    t_skip(5, 'QP solver (BPMPD_MEX or Optimization Toolbox) not available');
end

t_end;

return;
